<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Voer een profielnaam in.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Er is al een profiel met die naam.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Repo-pad:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Geef de locatie op van de Borg-repo</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>Repo-url:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>De repo kan niet worden toegevoegd.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Voer een geldige repo-url in of kies een lokaal pad.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Deze repo is al toegevoegd.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Wachtwoorden tonen</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Automatisch ingevuld wachtwoord door wachtwoorbeheerder.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Wachtwoorden verbergen</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Nieuwe back-uprepo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>Repo-url:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Kies een lokaal pad.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Versleuteling:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>SSH-sleutel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>SSH-sleutel automatisch genereren (standaard)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Opdrachtregelopties:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Borg-toegangszin:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Toegangszin bevestigen:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation>Tekstlabel</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Archieven van %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Archieven</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Voorvertoning: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Fout in archiefnaamsjabloon.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Opruimen voltooid.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>De archieven zijn ververst.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Aankoppelpunt kiezen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Aankoppelen voltooid.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Het aankoppelpunt is niet in gebruik.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Afkoppelen voltooid.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="392"/>
        <source>Select an archive to restore first.</source>
        <translation>Kies een te herstellen archief.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="412"/>
        <source>Choose Extraction Point</source>
        <translation>Kies een uitpaklocatie</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="475"/>
        <source>Archive deleted.</source>
        <translation>Het archief is verwijderd.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="460"/>
        <source>Confirm deletion</source>
        <translation>Verwijderen bevestigen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="560"/>
        <source>No archive selected</source>
        <translation>Geen archief gekozen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="460"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Weet je zeker dat je het archief wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="448"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Handeling afgebroken.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Het afkoppelen is mislukt. Zorg er voor dat er ‘{}‘ niet in gebruik is door andere programma&apos;s.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Selecteer een archief.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="533"/>
        <source>Change name</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="533"/>
        <source>New archive name:</source>
        <translation>Nieuwe archiefnaam:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="543"/>
        <source>Archive name cannot be blank.</source>
        <translation>Geef het archief een naam.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="548"/>
        <source>An archive with this name already exists.</source>
        <translation>Er is al een archief met deze naam.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="564"/>
        <source>Archive renamed.</source>
        <translation>De archiefnaam is gewijzigd.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Het archief is ververst.</translation>
    </message>
</context>
<context>
    <name>BorgBreakThread</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation>Bezig met openbreken van reposlot…</translation>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation>Het reposlot is opengebroken. Maak je recentste actie ongedaan.</translation>
    </message>
</context>
<context>
    <name>BorgCheckThread</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation>Bezig met starten van integriteitscontrole…</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="13"/>
        <source>Check completed.</source>
        <translation>Controle afgerond.</translation>
    </message>
</context>
<context>
    <name>BorgCreateThread</name>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation>Back-up voltooid.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation>Back-up gestart.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation>De back-up is afgerond, maar met waarschuwingen. Bekijk voor meer informatie het logboek.</translation>
    </message>
</context>
<context>
    <name>BorgDeleteThread</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation>Bezig met verwijderen…</translation>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation>Het archief is verwijderd.</translation>
    </message>
</context>
<context>
    <name>BorgDiffThread</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation>Bezig met opvragen van verschillen tussen archieven…</translation>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation>De verschillen zijn verkregen.</translation>
    </message>
</context>
<context>
    <name>BorgExtractThread</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation>Bezig met downloaden van bestanden uit archief…</translation>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation>De bestanden zijn hersteld uit het archief.</translation>
    </message>
</context>
<context>
    <name>BorgInfoArchiveThread</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation>Bezig met verversen van archieven…</translation>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation>Het archief is ververst.</translation>
    </message>
</context>
<context>
    <name>BorgInfoRepoThread</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation>Bezig met valideren van bestaande repo…</translation>
    </message>
</context>
<context>
    <name>BorgInitThread</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation>Bezig met instellen van nieuwe repo…</translation>
    </message>
</context>
<context>
    <name>BorgListArchiveThread</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation>Bezig met ophalen van archiefinhoud…</translation>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation>De archiefinhoud is opgehaald.</translation>
    </message>
</context>
<context>
    <name>BorgListRepoThread</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation>Bezig met verversen van archieven…</translation>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation>De archieven zijn ververst.</translation>
    </message>
</context>
<context>
    <name>BorgMountThread</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation>Bezig met aankoppelen van archief in map…</translation>
    </message>
</context>
<context>
    <name>BorgPruneThread</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation>Bezig met vernietigen van oude archieven…</translation>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation>De archieven zijn vernietigd.</translation>
    </message>
</context>
<context>
    <name>BorgThread</name>
    <message>
        <location filename="../../borg/borg_thread.py" line="297"/>
        <source>Task started</source>
        <translation>Taak gestart</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="54"/>
        <source>Files</source>
        <translation>Bestanden</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="55"/>
        <source>Original</source>
        <translation>Origineel</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="56"/>
        <source>Deduplicated</source>
        <translation>Uitgepakt</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="57"/>
        <source>Compressed</source>
        <translation>Ingepakt</translation>
    </message>
</context>
<context>
    <name>BorgUmountThread</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation>Bezig met ontkoppelen…</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Archief:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 van 16 november 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Let op: als je een hoofdmap selecteert, maar de onderliggende mappen deselecteert, worden ze alsnog hersteld.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Uitpakken</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Back-upprofiel toevoegen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Met back-upprofielen kun je back-ups van verschillende bronnen maken naar verschillende bestemmingen, zoals belangrijke documenten naar een externe repo via wifi en tegelijkertijd een volledige back-up op een lokaal opslagapparaat.&lt;/p&gt;&lt;p&gt;Repo&apos;s en ssh-sleutels worden gedeeld tussen profielen. Bronmappen, actieve bestemmingsrepo, toegestane netwerken, vernietigen, validatie en tijdschema&apos;s werken per profiel.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Profielnaam</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>SSH-sleutel genereren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Sleutelformaat:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Sleutellengte:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 of 4096 voor RSA, 384 of 521 voor ECDSA. Vaste waarde voor Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Meer&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Uitvoerbestand:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Pas dit niet aan als je wilt dat ssh de sleutel automatisch detecteert.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Genereren, en kopiëren naar klembord</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Selecteer twee archieven</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Aankoppelpunt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Verschil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Verschil tussen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>en</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>Oké</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Als je dit inschakelt, dan wordt je toegangszin gedeeld tijdens het delen. Wees voorzichtig hiermee!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Borg-toegangszin delen tijdens exporteren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Borg-toegangszin:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Bestaand profiel overschrijven</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Bestaande instellingen overschrijven</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Profielnaam wijzigen</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Verbinden met externe repo</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Wachtwoord tonen</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Wachtwoord verbergen</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Profiel exporteren</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>De huidige export is niet voorzien van een wachtwoord</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Export opslaan</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Fout tijdens exporteren</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>‘{}’ kan niet worden aangemaakt - kies een andere locatie.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Het exporteren is voltooid!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>De export is opgeslagen in {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Archieven</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Aankoppelpunt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Controleren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Vernietigen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Herladen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Opties omtrent vernietigen en archiefnamen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Behouden</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="253"/>
        <source>Use -1 for unlimited.</source>
        <translation>Gebruik -1 voor oneindig.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="246"/>
        <source> hourly, </source>
        <translation> per uur, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="263"/>
        <source> daily, </source>
        <translation> per dag, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="277"/>
        <source> weekly, </source>
        <translation> per week, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="291"/>
        <source> monthly and</source>
        <translation> per maand en</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="305"/>
        <source> annual archives</source>
        <translation> jaarlijkse archieven</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="332"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Behoud alle archieven van de afgelopen:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="342"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24u, 1d, 52w, 12m, 1j</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="382"/>
        <source>Archive Name:</source>
        <translation>Archiefnaam:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="425"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Beschikbare variabelen: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="392"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="435"/>
        <source>Prune Prefix:</source>
        <translation>Vernietigprefix:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Repo:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Kies een back-upbestemming</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Repo ontkoppelen (hiermee verwijder je geen gegevens, en je kunt hem later altijd opnieuw koppelen)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>SSH-sleutel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Kopieer de ssh-sleutel naar het klembord.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Beveilig je repo&apos;s met een sleutel. Gebruik één van de bestaande of maak nieuwe aan.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Compressie:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Versleuteling:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Oorspronkelijke grootte:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>Grootte na uitpakken:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>Grootte na inpakken:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="47"/>
        <source>Schedule</source>
        <translation>Tijdschema</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="73"/>
        <source>Backup manually</source>
        <translation>Handmatig back-uppen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="90"/>
        <source>Backup every </source>
        <translation>Maak een back-up, elke</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="113"/>
        <source>hours at</source>
        <translation>uur om</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="136"/>
        <source>minutes past the hour</source>
        <translation>minuten na het hele uur</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="160"/>
        <source>Backup daily at</source>
        <translation>Maak een back-up, dagelijks om</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="190"/>
        <source>Validate repository data every</source>
        <translation>Valideer repo-gegevens elke</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="216"/>
        <source>weeks</source>
        <translation>weken</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="243"/>
        <source>Prune old Archives after each backup</source>
        <translation>Oude archieven vernietigen na elke back-up</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="283"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="312"/>
        <source>Next Backup:</source>
        <translation>Volgende back-up:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="319"/>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="363"/>
        <source>Networks</source>
        <translation>Netwerken</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="375"/>
        <source>Allowed Networks:</source>
        <translation>Toegestane netwerken:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="424"/>
        <source>Log</source>
        <translation>Logboek</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="450"/>
        <source>Time</source>
        <translation>Tijd</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="455"/>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="460"/>
        <source>Subcommand</source>
        <translation>Subopdracht</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="465"/>
        <source>Repository</source>
        <translation>Repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="470"/>
        <source>Returncode</source>
        <translation>Terugkoppelingscode</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="487"/>
        <source>Shell Commands</source>
        <translation>Shell-opdrachten</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Voer aangepaste shellopdrachten uit vóór en ná elke back-up. De back-up- en na-back-upopdrachten worden alleen uitgevoerd als de voor-back-upopdracht geen fouten aangeeft (terugkoppelcode 0).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="515"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Voor-back-upopdracht, uit te voeren VÓÓR back-ups</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="525"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Na-back-upopdracht, uit te voeren NÁ back-ups</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Beschikbare env-variabelen: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Te back-uppen bronmappen en -bestanden:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Map toevoegen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Uitsluiten, indien aanwezig (bestanden met de volgende bestanden uitsluiten):</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Verschil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Archieven kunnen alleen worden aangekoppeld met &amp;quot;FUSE voor macOS&amp;quot; - &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Downloaden&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Met vernietigen verwijder je oude archieven. Je kunt het aantal uurlijkse, dagelijkse, etc. te behouden archieven bepalen. Meestal willen gebruikers meer nieuwere en minder oudere archieven behouden.&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;Meer informatie&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Vorta-versie:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Bug melden&lt;/span&gt;&lt;/a&gt; |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Logboek&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Borg-versie:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Externe of lokale back-uprepo. Wil je eenvoudige, veilige back-uphosting? Probeer dan eens &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;De toe te passen compressie op nieuwe gegevens. Kan worden gewijzigd en is niet van toepassing op uitpakken. &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Meer informatie&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Uitsluitpatronen (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;meer&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>Bijv. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>Bijv. geenbackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Repo-url kopiëren naar klembord</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="382"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Geen back-ups uitvoeren op netwerken met beperkte data</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Bestand(en) toevoegen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>Eén bestand of map per regel</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Bestanden/Mappen plakken</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="428"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{momenteel:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Pad</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Aantal bestanden</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Groottes herberekenen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Geselecteerd archief</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="562"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Voeg de volgende opties toe bij het maken van een back-up. Bekijk voor meer informatie de &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;documentatie&lt;/span&gt;&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="578"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>De toe te voegen opties, bijv. --dry-run</translation>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="24"/>
        <source>Import Profile</source>
        <translation>Profiel importeren</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="32"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>De toegangszin is geladen uit het exportbestand</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="39"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>De toegangszin is geladen uit je sleutelbos</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="49"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Er bestaat geen profiel met de naam ‘{}’ - er kan dus niks worden overschreven.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="60"/>
        <source>Error while importing</source>
        <translation>Fout tijdens importeren</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="76"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Het schema kan niet worden bijgewerkt. Stel een bugmelding op via de link op het tabblad ‘Overig’. Stuur de volgende informatie mee:

 {0}
 {1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="79"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Nieuwe exportbestanden kunnen niet worden gebruikt in oudere versies.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="81"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Het exportbestand kan niet worden uitgelezen wegens een toegangsfout.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="83"/>
        <source>Profile export file not found.</source>
        <translation>Het exportbestand is niet aangetroffen.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="256"/>
        <source>Task cancelled</source>
        <translation>Taak afgebroken</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>Hoofdvenster</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Huidig profiel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Profielnaam wijzigen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Profiel verwijderen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Bronnen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Tijdschema</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Archieven</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Overig</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Back-up starten</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Recentste</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Standaardwaarden</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Profiel toevoegen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="165"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Weet je zeker dat je ‘{}’ wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="166"/>
        <source>Confirm deletion</source>
        <translation>Verwijderen bevestigen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="273"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Wil je dat Vorta blijft draaien op de achtergrond?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="279"/>
        <source>Don&apos;t show this again</source>
        <translation>Niet meer tonen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="84"/>
        <source>Import from file...</source>
        <translation>Importeren uit bestand…</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="177"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Het laatste profiel kan niet worden verwijderd.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="205"/>
        <source>Profile import successful!</source>
        <translation>Het importeren is voltooid!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="205"/>
        <source>Profile {} imported.</source>
        <translation>‘{}’ is geïmporteerd.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="214"/>
        <source>Load profile</source>
        <translation>Profiel laden</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="214"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Alle bestanden (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Profiel exporteren</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="223"/>
        <source>Failed to import profile</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ Nieuwe repo aanmaken</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Bestaande repo toevoegen</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Geen compressie</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>SSH-sleutel automatisch genereren (standaard)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Nieuwe sleutel genereren</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>De sleutel is gekopieerd naar het klembord</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>De geselecteerde ssh-sleutel is gekopieerd naar het klembord. Gebruik deze om externe repobevoegdheden in te stellen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Geen openbare sleutel aangetroffen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Kies een openbare sleutel in het uitklapmenu.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>De repo is ontkoppeld</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Je kunt deze later opnieuw koppelen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (modern, standaard)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard, niveau 3 (modern)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard, niveau 8 (modern)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB, niveau 6 (automatisch, verouderd)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA, niveau 6 (automatisch, verouderd)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Kies een repo in het uitklapmenu.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (aanbevolen)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (verouderd)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Hoog (aanbevolen)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Het sleutelbestand bestaal al en wordt niet overschreven.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>De nieuwe sleutel is gekopieerd naar het klembord en weggeschreven naar %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Fout tijdens sleutelgenerate.</translation>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="171"/>
        <source>Choose directory to back up</source>
        <translation>Kies de te back-uppen map</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="171"/>
        <source>Choose file(s) to back up</source>
        <translation>Kies de te back-uppen bestanden</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="128"/>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="132"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Bezig met berekenen…</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="162"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Je hebt geen leestoegang tot {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="43"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta voor Borg Backup</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Backup in Progress</source>
        <translation>Er wordt een back-up gemaakt</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Back-uppen afbreken</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Volgende taak: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Nu back-uppen</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Vorta-back-up</translation>
    </message>
    <message>
        <location filename="../../application.py" line="186"/>
        <source>No Borg Binary Found</source>
        <translation>Borg is niet aangetroffen</translation>
    </message>
    <message>
        <location filename="../../application.py" line="187"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorta heeft Borg niet aangetroffen op je systeem.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="224"/>
        <source>Repository In Use</source>
        <translation>De repo is in gebruik</translation>
    </message>
    <message>
        <location filename="../../application.py" line="226"/>
        <source>Abort</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <location filename="../../application.py" line="227"/>
        <source>Continue</source>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>De repo, {repo_url}, is mogelijk al in gebruik.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="230"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Breek het slot alleen open als er geen ander Borg-proces actief is. Wil je afbreken of het slot openbreken?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="238"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Je hebt geen toegang tot de repo ‘{repo_url}’. Verkrijg toegang en probeer het opnieuw.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="241"/>
        <source>No Repository Permissions</source>
        <translation>Niet bevoegd</translation>
    </message>
    <message>
        <location filename="../../application.py" line="205"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Vorta heeft volledige schijftoegang nodig om volledige back-ups te kunnen maken</translation>
    </message>
    <message>
        <location filename="../../application.py" line="206"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Zonder deze toegang zijn sommige bestanden ontoegankelijk, wat kan leiden tot een onvolledige back-up. Verleen de bevoegdheid &lt;b&gt;Volledige schijftoegang&lt;/b&gt;  via &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Systeemvoorkeuren &gt; Beveiliging en privacy&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="278"/>
        <source>Profile import successful!</source>
        <translation>Het importeren is voltooid!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="278"/>
        <source>Profile {} imported.</source>
        <translation>‘{}’ is geïmporteerd.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="265"/>
        <source>Failed to import profile</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="265"/>
        <source>Failed to import a profile from {}:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="265"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler_old.py" line="95"/>
        <source>None scheduled</source>
        <translation>Niks ingepland</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="126"/>
        <source>Vorta Backup</source>
        <translation>Vorta-back-up</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="104"/>
        <source>Starting background backup for %s.</source>
        <translation>Er wordt een achtergrondback-up gestart voor %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="115"/>
        <source>Backup successful for %s.</source>
        <translation>%s is gebackupt.</translation>
    </message>
    <message>
        <location filename="../../scheduler_old.py" line="121"/>
        <source>Error during backup creation.</source>
        <translation>Fout tijdens aanmaken van back-up.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Fatale fout</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Niet-opgevangen uitzondering. Meld dit, inclusief de bijbehorende tekst, op
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/borg_thread.py" line="117"/>
        <source>Backup is already in progress.</source>
        <translation>Er wordt al een back-up gemaakt.</translation>
    </message>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Borg is niet aangetroffen.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="125"/>
        <source>Add a backup repository first.</source>
        <translation>Voeg eerst een back-uprepo toe.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Voeg eerst te back-uppen mappen toe.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Niet toegestaan op het huidige wifi-netwerk.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>De repomap is niet aangekoppeld of verplaatst.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>De voor-back-upopdracht koppelde afsluitcode nul terug.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Bezig met starten van back-up…</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Geen actieve Borg-aankoppelpunten aangetroffen.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="129"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Je Borg-versie is verouderd. &gt;=1.1.0 is vereist.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Je huidige Borg-versie heeft geen ondersteuning voor ZStd-compressie.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Er wordt geen back-up uitgevoerd op een netwerk met beperkte data.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="42"/>
        <source>Please unlock your password manager.</source>
        <translation>Ontgrendel je wachtwoordbeheerder.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="155"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>De toegangszin van je repo is opgeslagen in een wachtwoordbeheerder die niet meer beschikbaar is.
Herkoppel je repo.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_thread.py" line="139"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Ontgrendel je wachtwoordbeheerder of schakel deze optie uit op het tabblad ‘Overig’.</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="../../models.py" line="205"/>
        <source>Display notifications when background tasks fail</source>
        <translation>Meldingen tonen als achtergrondtaken mislukken</translation>
    </message>
    <message>
        <location filename="../../models.py" line="210"/>
        <source>Also notify about successful background tasks</source>
        <translation>Meldingen tonen als achtergrondtaken zijn afgerond</translation>
    </message>
    <message>
        <location filename="../../models.py" line="215"/>
        <source>Automatically start Vorta at login</source>
        <translation>Vorta automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../../models.py" line="255"/>
        <source>Check for updates on startup</source>
        <translation>Automatisch controleren op updates</translation>
    </message>
    <message>
        <location filename="../../models.py" line="260"/>
        <source>Include pre-release versions when checking for updates</source>
        <translation>Controleren op vooraf vrijgeven versies</translation>
    </message>
    <message>
        <location filename="../../models.py" line="220"/>
        <source>Open main window on startup</source>
        <translation>Hoofdvenster tonen na opstarten</translation>
    </message>
    <message>
        <location filename="../../models.py" line="225"/>
        <source>Get statistics of file/folder when added</source>
        <translation>Statistieken van map/bestand tonen na toevoegen</translation>
    </message>
    <message>
        <location filename="../../models.py" line="268"/>
        <source>Display background exit dialog</source>
        <translation>Afsluitvenster tonen als Vorta op de achtergrond draait</translation>
    </message>
    <message>
        <location filename="../../models.py" line="235"/>
        <source>Try to replace existing permissions when mounting an archive.</source>
        <translation>Vervang de  bestaande rechten tijdens het aankoppelen van een archief.</translation>
    </message>
    <message>
        <location filename="../../models.py" line="230"/>
        <source>Store repository passwords in system keychain, if available.</source>
        <translation>Sla repo-wachtwoorden op in de sleutelbeheerder van het systeem (indien beschikbaar).</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="329"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>De wachtwoorden moeten identiek zijn en meer dan 8 tekens bevatten.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="331"/>
        <source>Passwords must be identical.</source>
        <translation>De wachtwoorden moeten identiek zijn.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="333"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>De wachtwoorden moeten meer dan 8 tekens bevatten.</translation>
    </message>
</context>
</TS>